## What is Pyjamas?

Pyjamas is a Rich Internet Application (RIA) Development Platform for both Web and Desktop.

It contains a Python-to-Javascript compiler, an AJAX framework and a Widget Set API. Pyjamas started life as a Python port of Google Web Toolkit, the Java-to-Javascript compiler. Read the FAQ and the list of features.

## What is Pyjamas Desktop?

Pyjamas Desktop is the Desktop version of Pyjamas

Pyjamas Desktop allows the exact same python web application source code to be executed as a standalone desktop application (running under Python) instead of being stuck in a Web browser.

For Free Software platforms, most Linux Distributions now come with Pyjamas and Pyjamas Desktop pre-packaged: Debian/Testing, FC13, ArchLinux and Gentoo.

For Windows, Pyjamas Desktop uses MSHTML. Since MSHTML comes pre-installed on Windows (as part of IE), there is very little extra to download (other than Python itself).

## Why should I use Pyjamas?

You can write web applications in python - a readable programming language - instead of in HTML and Javascript, both of which become quickly unreadable for even medium-sized applications. Your application's design can benefit from encapsulating high level concepts into classes and modules (instead of trying to fit as much HTML as you can stand into one page); you can reuse - and import - classes and modules.

Also, the AJAX library takes care of all the browser interoperability issues on your behalf, leaving you free to focus on application development instead of learning all the "usual" browser incompatibilities.

## I don't get it

Fear not - you are not alone: the true purpose and nature of Pyjamas is blissfully opaque to many. Will and Abe come to the rescue, with their Guide to Pyjamas. On mature reflection, however, it's probably best to read the FAQ and then contact the people on the mailing list.

## Who are the developers?

- The original code for the UI Widget Set and the DOM support libraries came from GWT, and was ported by James Tauber. James wrote the original pyjs compiler.
- Luke Leighton took over the project in 2008, and updated the UI Widget Set, improved the compiler and created the three Pyjamas Desktop runtimes. He has been maintaining and driving the project ever since.
- Bernd Dorn and his colleagues from Lovely Systems did some dramatic compiler improvements for 0.5.
- Kees Bos joined because he was not interested in learning JavaScript, but learn he definitely did. Kees is responsible for the majority of the vast improvements and the more esoteric python interoperability in the compiler, such as "yield", long data type and much much more.
- In total, there are around fifty contributors to the Pyjamas Project: a complete list can be found in the copyright file in the Pyjamas distribution.

The code for the Pyjamas Web Site, which is itself a Pyjamas application, was written by Luke Leighton. It has some pretty cool features, none of which "stand out", which is as it should be. Technology is not there to "dazzle" people or get in the way by promoting itself and its own "glory": it's there to make peoples' lives simpler and easier.